@@ -23,6 +23,7 @@ typedef enum {
   NSTimer *_dayTimer;
   int bezeledCell;
   id _dataSource;
+  BOOL horizontalDisplay;
 }
 
 - (id)initWithFrame:(NSRect)frame;
@@ -34,6 +35,7 @@ typedef enum {
 - (id)dataSource;
 - (void)setDataSource:(id)dataSource;
 - (void)reloadData;
+- (void)dataChanged:(NSNotification *)not;
 @end
 
 @interface NSObject(CalendarViewDelegate)
@@ -41,7 +43,3 @@ typedef enum {
 - (void)calendarView:(CalendarView *)cs currentDateChanged:(Date *)date;
 - (void)calendarView:(CalendarView *)cs userActionForDate:(Date *)date;
 @end
-
-@interface NSObject(CalendarViewDataSource)
-- (CVCellStatus)calendarView:(CalendarView *)view cellStatusForDate:(Date *)date;
-@end
